# Changelog

All notable changes to this project will be documented in this file.

## v2.0.2 - 2022, Apr 28

**Changed:**

- fix slow reading of SBML files

## v2.0.1 - 2022, Mar 23

**Changed:**

- fix regression in clyngor_with_clingo
- requires Python >= 3.7

## v2.0.0 - 2020, Mar 5

**Changed:**

- use clyngor_with_clingo instead pyasp-1.4.3
- requires Python >= 3.6.

## v1.5.2 - 2017, Mar 29

**Changed:**

- use pyasp-1.4.3
- Correctly handle import reactions in the repair db.

## v1.5.0 - 2016, Feb 23

**Changed:**

- Make repairnet optional.
- If no repairnet is set meneco only performs a producibility check.

## v1.4.3 - 2015, Nov 23

**Changed:**

- port to python 3
- use pyasp-1.4.2

## v1.4.2 - 2014, May 21

**Changed:**

- use pyasp-1.3.3

## v1.4.1 - 2014, Mar 6

**Changed:**

- use pyasp-1.3.1

## v1.4 - 2014, Mar 4

**Changed:**

- use pyasp-1.3

## Undocumented versions

- v1.3.2
- v1.3.1
- v1.3
- v1.2
- v1.1
- v1.0dev
